@@ -293,7 +293,11 @@ plugin_couchdb_contacts (EPlugin *epl, EConfigHookItemFactoryData *data)
 }
 
 gint
+#if EDS_MINOR_VERSION < 30
 e_plugin_lib_enable (EPluginLib *ep, gint enable)
+#else
+e_plugin_lib_enable (EPlugin *ep, gint enable)
+#endif
 {
 	if (enable)
 		ensure_couchdb_contacts_source_group ();
